Learn R Programming

SkeletalVis (version 0.1.2)

browse_skeletalvis: Browse the skeletalvis database metadata

Description

Opens an interactive table showing the experiments available for analysis. Row can be selected to return the datasetID for the comparison of interest within that experiment.

Usage

browse_skeletalvis(skeletalvis)

Value

The datasetID of the selected gene expression profile from the interactive table.

Arguments

skeletalvis

The path to the SkeletalVis data folder.

Examples

Run this code
if(interactive()){
skeletalvis <- load_skeletalvis(demo=TRUE)
selected_id <- browse_skeletalvis(skeletalvis)
}

Run the code above in your browser using DataLab