Learn R Programming

SkeletalVis (version 0.1.2)

view_prioritised_oagenes: View prioritised osteoarthritis associated genes

Description

Retrieves the machine learning model prioritised table of osteoarthritis joint damage in animals. Genes are ranked by their probability to cause an OA damage phenotype when experimentally perturbed. The predicted direction of effect and druggability of that gene is also provided.

Usage

view_prioritised_oagenes(skeletalvis)

Value

A data frame with the following columns:

Gene

The human gene symbol.

Rank

The rank of the priortisation scores from the machine learning model

PredictedEffect

The predicted effect this gene

Category_sm

The small molecular tractibility of this gene

Category_ab

The antibody tractibility of this gene

Arguments

skeletalvis

The path to the SkeletalVis folder.

Examples

Run this code
skeletalvis <- load_skeletalvis(demo=TRUE)
oatargets <- view_prioritised_oagenes(skeletalvis)

Run the code above in your browser using DataLab