Allows search and visualisation of a collection of uniformly processed skeletal transcriptomic datasets. Includes methods to identify datasets where genes of interest are differentially expressed and find datasets with a similar gene expression pattern to a query dataset Soul J, Hardingham TE, Boot-Handford RP, Schwartz JM (2019) tools:::Rd_expr_doi("10.1093/bioinformatics/bty947").
Maintainer: Jamie Soul jamie.soul@liverpool.ac.uk [copyright holder]
Useful links: