browse_skeletalvis: Browse the skeletalvis database metadata
Description
Opens an interactive table showing the experiments available for analysis.
Row can be selected to return the datasetID for the comparison of interest within that experiment.
Usage
browse_skeletalvis(skeletalvis)
Value
The datasetID of the selected gene expression profile from the interactive table.