powered by
Checks the default SkeletalVis data location for the differential expression data and metadata files. If any files are missing, it lists them and ask permission to download the missing files.
load_skeletalvis( verbose = TRUE, ask = TRUE, demo = FALSE, force_update = FALSE )
The path to the SkeletalVis data folder.
Logical. If TRUE, prints messages about file existence and download status. Default is TRUE
Logical. If TRUE, prompts the user for confirmation before downloading missing files. Default is TRUE.
Logical. If TRUE, uses built in demo data suitable for testing the package functions. Default is FALSE
Logical. If TRUE, re-downloads all data files even if present. Default is FALSE
# Load the demo SkeletalVis data. skeletalvis <- load_skeletalvis(demo = TRUE) # Download full dataset (only if running interactively) if (interactive()) { skeletalvis <- load_skeletalvis() }
Run the code above in your browser using DataLab