Retrieves the machine learning model prioritised table of osteoarthritis joint damage in animals.
Genes are ranked by their probability to cause an OA damage phenotype when experimentally perturbed.
The predicted direction of effect and druggability of that gene is also provided.
Usage
view_prioritised_oagenes(skeletalvis)
Value
A data frame with the following columns:
Gene
The human gene symbol.
Rank
The rank of the priortisation scores from the machine learning model